@@ -1,12 +1,16 @@
 import json
+import sqlite3
+import sys
+import uuid
 
 import duckdb
 import psycopg2
-import uuid
 from tqdm import tqdm
+
 from ._camelcase import _decode_camel_case
-from ._sqlx import _server_cursor
+from ._sqlx import _cast_to_varchar
 from ._sqlx import _encode_sql
+from ._sqlx import _server_cursor
 from ._sqlx import _sqlid
 from ._sqlx import _varchar_type
 
@@ -63,7 +67,7 @@ def _old_drop_json_tables(db, table):
                 pass
             finally:
                 cur2.close()
-    except (duckdb.CatalogException, RuntimeError, psycopg2.Error):
+    except (RuntimeError, psycopg2.Error, sqlite3.OperationalError, duckdb.CatalogException):
         pass
     finally:
         cur.close()
@@ -94,7 +98,7 @@ def _drop_json_tables(db, table):
                 pass
             finally:
                 cur2.close()
-    except (duckdb.CatalogException, RuntimeError, psycopg2.Error):
+    except (RuntimeError, psycopg2.Error, sqlite3.OperationalError, duckdb.CatalogException):
         pass
     finally:
         cur.close()
@@ -189,8 +193,8 @@ def _compile_attrs(dbtype, parents, prefix, jdict, newattrs, depth, max_depth, q
         _compile_attrs(dbtype, parents + p, _decode_camel_case(b[0]) + '__', b[1], newattrs, depth + 1, max_depth, qkey)
     for y in arrays:
         p = [(1, _decode_camel_case(y[2]))]
-        _compile_array_attrs(dbtype, parents + p, _decode_camel_case(y[0]) + '__', y[1], newattrs, depth + 1, y[0], max_depth,
-                             qkey)
+        _compile_array_attrs(dbtype, parents + p, _decode_camel_case(y[0]) + '__', y[1], newattrs, depth + 1, y[0],
+                             max_depth, qkey)
 
 
 def _transform_array_data(dbtype, prefix, cur, parents, jarray, newattrs, depth, row_ids, arrayattr, max_depth,
@@ -310,8 +314,9 @@ def _transform_json(db, dbtype, table, total, quiet, max_depth):
     try:
         cur.execute('SELECT * FROM ' + _sqlid(table) + ' LIMIT 1')
         for a in cur.description:
-            if a[1] == 3802 or a[1] == 'STRING' or a[1] == 1043:
-                str_attrs.append(a[0])
+            str_attrs.append(a[0])
+            # if a[1] == 3802 or a[1] == 'STRING' or a[1] == 1043:
+            #     str_attrs.append(a[0])
     finally:
         cur.close()
     # Scan data for JSON objects
@@ -322,7 +327,8 @@ def _transform_json(db, dbtype, table, total, quiet, max_depth):
     newattrs = {}
     cur = _server_cursor(db, dbtype)
     try:
-        cur.execute('SELECT ' + ','.join([_sqlid(a)+'::varchar' for a in str_attrs]) + ' FROM ' + _sqlid(table))
+        cur.execute('SELECT ' + ','.join([_cast_to_varchar(_sqlid(a), dbtype) for a in str_attrs]) + ' FROM ' +
+                    _sqlid(table))
         pbar = None
         pbartotal = 0
         if not quiet:
@@ -386,7 +392,8 @@ def _transform_json(db, dbtype, table, total, quiet, max_depth):
         return [], {}
     cur = _server_cursor(db, dbtype)
     try:
-        cur.execute('SELECT ' + ','.join([_sqlid(a)+'::varchar' for a in json_attrs]) + ' FROM ' + _sqlid(table))
+        cur.execute('SELECT ' + ','.join([_cast_to_varchar(_sqlid(a), dbtype) for a in json_attrs]) + ' FROM ' +
+                    _sqlid(table))
         pbar = None
         pbartotal = 0
         if not quiet:
@@ -414,6 +421,9 @@ def _transform_json(db, dbtype, table, total, quiet, max_depth):
                 pbar.update(1)
         if not quiet:
             pbar.close()
+    except (RuntimeError, psycopg2.Error, sqlite3.OperationalError, duckdb.CatalogException) as e:
+        print('ldlite: running JSON transform: ' + repr(e), file=sys.stderr)
+        return [], {}
     finally:
         cur.close()
     db.commit()
@@ -423,6 +433,9 @@ def _transform_json(db, dbtype, table, total, quiet, max_depth):
         cur.execute('CREATE TABLE ' + _sqlid(tcatalog) + '(table_name ' + _varchar_type(dbtype) + ' NOT NULL)')
         for t in newattrs.keys():
             cur.execute('INSERT INTO ' + _sqlid(tcatalog) + ' VALUES(' + _encode_sql(dbtype, t) + ')')
+    except (RuntimeError, psycopg2.Error, sqlite3.OperationalError, duckdb.CatalogException) as e:
+        print('ldlite: writing table catalog for JSON transform: ' + repr(e), file=sys.stderr)
+        return [], {}
     finally:
         cur.close()
     db.commit()
